@@ -1,7 +1,8 @@
 from __future__ import annotations
 
+from collections.abc import Mapping, Sequence
 from pathlib import Path
-from typing import Any, Mapping, Sequence, Set
+from typing import Any
 
 from tox.config.set_env import SetEnv
 from tox.config.types import Command, EnvList
@@ -9,11 +10,12 @@ from tox.tox_env.python.pip.req_file import PythonDeps
 
 
 def stringify(value: Any) -> tuple[str, bool]:  # noqa: PLR0911
-    """
-    Transform a value into a string representation.
+    """Transform a value into a string representation.
 
     :param value: the value in question
-    :return: a tuple, first the value as str, second a flag if the value if a multi-line one
+
+    :returns: a tuple, first the value as str, second a flag if the value if a multi-line one
+
     """
     if isinstance(value, str):
         return value, False
@@ -21,8 +23,10 @@ def stringify(value: Any) -> tuple[str, bool]:  # noqa: PLR0911
         return str(value), False
     if isinstance(value, Mapping):
         return "\n".join(f"{stringify(k)[0]}={stringify(v)[0]}" for k, v in value.items()), True
-    if isinstance(value, (Sequence, Set)):
+    if isinstance(value, Sequence):
         return "\n".join(stringify(i)[0] for i in value), True
+    if isinstance(value, set):  # sort it to make it stable
+        return "\n".join(sorted(stringify(i)[0] for i in value)), True
     if isinstance(value, EnvList):
         return "\n".join(e for e in value.envs), True
     if isinstance(value, Command):
