@@ -340,7 +340,18 @@ def test_show_config_matching_env_section(tox_project: ToxProjectCreator) -> Non
 
 def test_package_env_inherits_from_pkgenv(tox_project: ToxProjectCreator, demo_pkg_inline: Path) -> None:
     project = tox_project({"tox.ini": "[pkgenv]\npass_env = A, AA\ndeps=C\n D"})
-    outcome = project.run("c", "--root", str(demo_pkg_inline), "-k", "deps", "pass_env", "-e", "py,.pkg")
+    outcome = project.run(
+        "c",
+        "--root",
+        str(demo_pkg_inline),
+        "--workdir",
+        str(project.path / ".tox"),
+        "-k",
+        "deps",
+        "pass_env",
+        "-e",
+        "py,.pkg",
+    )
     outcome.assert_success()
     exp = """
     [testenv:.pkg]
