@@ -2,9 +2,10 @@ from __future__ import annotations
 
 import sys
 import sysconfig
+from pathlib import Path
 from types import SimpleNamespace
 from typing import TYPE_CHECKING
-from unittest.mock import patch
+from unittest.mock import MagicMock, patch
 
 import pytest
 
@@ -13,7 +14,6 @@ from tox.tox_env.python.api import Python
 
 if TYPE_CHECKING:
     from collections.abc import Callable
-    from pathlib import Path
 
     from pytest_mock import MockerFixture
 
@@ -51,12 +51,21 @@ def test_build_wheel_in_non_base_pkg_env(
     demo_pkg_inline: Path,
     mocker: MockerFixture,
 ) -> None:
-    mocker.patch("tox.tox_env.python.virtual_env.api.session_via_cli")
+    def _fake_session(env_dir: list[str], **_: object) -> MagicMock:
+        bin_dir = Path(env_dir[0]) / "bin"
+        bin_dir.mkdir(parents=True, exist_ok=True)
+        (bin_dir / "python").symlink_to(sys.executable)
+        mock = MagicMock()
+        mock.creator.bin_dir = bin_dir
+        mock.creator.script_dir = bin_dir
+        return mock
+
+    mocker.patch("tox.tox_env.python.virtual_env.api.session_via_cli", side_effect=_fake_session)
     prev_ver, impl = patch_prev_py(True)
     prev_py = f"py{prev_ver}"
     prj = tox_project({"tox.ini": f"[tox]\nenv_list= {prev_py}\n[testenv]\npackage=wheel"})
     execute_calls = prj.patch_execute(lambda r: 0 if "install" in r.run_id else None)
-    result = prj.run("-r", "--root", str(demo_pkg_inline))
+    result = prj.run("-r", "--root", str(demo_pkg_inline), "--workdir", str(prj.path / ".tox"))
     result.assert_success()
     calls = [(i[0][0].conf.name, i[0][3].run_id) for i in execute_calls.call_args_list]
     assert calls == [
